#
# spec file for package erofs-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           erofs-utils
Version:        1.6
Release:        bp154.2.3.1
Summary:        Utilities for the Extendable Read-Only Filesystem (EROFS)
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://git.kernel.org/pub/scm/linux/kernel/git/xiang/erofs-utils.git/

Source:         %name-%version.tar.xz
BuildRequires:  autoconf >= 2.69
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  xz
Supplements:    filesystem(erofs)
BuildRequires:  liblz4-devel >= 1.9
BuildRequires:  libuuid-devel

%description
mkfs.erofs is a user-space tool to create erofs filesystem images. It
can create two main types of erofs images, compressed and
uncompressed:

 * For compressed images, it is able to integrate several compression
   algorithms, LZ4 is supported according to the current erofs kernel
   implementation.
 * For uncompressed images, it can decide whether the last page of a
   file should be inlined or not properly.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure --bindir="%_sbindir"
%make_build

%install
%make_install

%files
%license COPYING
%_sbindir/*erofs
%_mandir/man1/*erofs*

%changelog
* Mon Apr 17 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to release 1.6
  * support fragments by using `-Efragments`
  * support compressed data deduplication by using `-Ededupe`
  * (erofsfuse) support extended attributes
  * (mkfs.erofs) support multiple algorithms in a single image
  * (mkfs.erofs) support chunk-based sparse files
  * (mkfs.erofs) add volume-label setting support
  * (mkfs.erofs) add uid/gid offsetting support
  * (mkfs.erofs) pack files entirely by using `-Eall-fragments`
  * various bugfixes and cleanups;
* Mon Jun 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.5
  * fsck.erofs: support filesystem extraction
  * support ztailpacking inline feature for compressed files
  * dump.erofs: support listing directories
  * more liberofs APIs (including iterate APIs)
  * use mtime to allow more control over the timestamps
* Sun Dec 19 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4
  * mkfs.erofs: support pre-defined UUIDs and SELinux file contexts
  * Support new big pcluster feature together with Linux 5.13+
  * Added support to override UID/GID
  * Introduced preliminary dump.erofs and fsck.erofs
  * Introduced MicroLZMA compression support
* Tue May 19 2020 David Michael <fedora.dm0@gmail.com>
- Update to release 1.1
  * add a manual for mkfs.erofs
  * add superblock checksum support
  * add filesystem UUID support
  * add exclude files support
* Fri Nov  8 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0
  * list available compressors for help command
  * introduce long parameter option
  * introduce shared xattr support
  * introduce inline xattr support
  * fix old kernel compatibility for non-lz4 compression
  * introduce fixed UNIX timestamp
  * complete extended inode support
  * support 64-bit internal buffer cache
  * keep up with in-kernel ondisk format naming
  * resize image to the correct size
  * complete special file support
- Drop long.patch (merged upstream)
* Sun Sep  8 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 20190826
  * fix up "-E legacy-compress"
  * fix a memory leak of compressmeta
  * fail the image creation when source path is not a directory file
- Add long.patch
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 20190803
  * The mkfs utility was rewritten
- Drop no-date.diff (no longer needed)
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Move to new git snapshot 72ae01c3e97c7b2de569b2b86ea4ed6b245acb72
  * No changelog was provided
- Drop constant.diff, no-static.diff (no longer needed)
* Mon Dec 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use lz4hc.h from bundled copy, not the system.
* Mon Nov 19 2018 Jan Engelhardt <jengelh@inai.de>
- Initial version (0.0.1~4 / 4f437e3) for build.opensuse.org
- Add constant.diff, no-static.diff, no-date.diff
